summaryrefslogtreecommitdiffstats
path: root/korn/systemtray.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/systemtray.h')
-rw-r--r--korn/systemtray.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/korn/systemtray.h b/korn/systemtray.h
index 54fba1a4f..3cf3fe2cc 100644
--- a/korn/systemtray.h
+++ b/korn/systemtray.h
@@ -35,10 +35,10 @@ class SystemTray : public KSystemTray
public:
/**
* This contructor gives all it parameters to its parents.
* @param parant The tqparent window
* @param name The name of the TQObject's parents.
*/
- SystemTray( TQWidget * tqparent = 0, const char * name = 0 );
+ SystemTray( TQWidget * parent = 0, const char * name = 0 );
/**
* Empty destructor; does nothing at the moment
*/
@@ -35,10 +35,10 @@ class SystemTray : public KSystemTray
/**
* This contructor gives all it parameters to its parents.
- * @param parant The tqparent window
+ * @param parant The parent window
* @param name The name of the TQObject's parents.
*/